==> librecad_2.0.9.orig.tar.gz: LibreCAD-2.0.9/librecad/src/actions/rs_actiondrawlinehorvert.h <==
/****************************************************************************
**
** This file is part of the LibreCAD project, a 2D CAD program
**
** Copyright (C) 2010 R. van Twisk (librecad@rvt.dds.nl)
** Copyright (C) 2001-2003 RibbonSoft. All rights reserved.
**
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software 
** Foundation and appearing in the file gpl-2.0.txt included in the
** packaging of this file.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
** This copyright notice MUST APPEAR in all copies of the script!  
**
**********************************************************************/

#ifndef RS_ACTIONDRAWLINEHORVERT_H
#define RS_ACTIONDRAWLINEHORVERT_H

#include "rs_previewactioninterface.h"

struct RS_LineData;

/**
 * This action class can handle user events to draw 
 * horizontal/vertical lines from a given startpoint
 * to an endpoint closest to a second given point.
 * OBSOLETE
 *
 * @author Ulf Lehnert
 */
class RS_ActionDrawLineHorVert : public RS_PreviewActionInterface {
	Q_OBJECT
public:
    /**
     * Action States.
     */
    enum Status {
        SetStartpoint,      /**< Setting the 1st point.  */
        SetEndpoint       /**< Setting the 2nd point. */
    };

public:
    RS_ActionDrawLineHorVert(RS_EntityContainer& container,
                             RS_GraphicView& graphicView);
    ~RS_ActionDrawLineHorVert();
	
	static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);

    void reset();

    virtual void init(int status=0);
    virtual void trigger();
    virtual void mouseMoveEvent(QMouseEvent* e);
    virtual void mouseReleaseEvent(QMouseEvent* e);
    virtual void updateMouseButtonHints();
    virtual void updateMouseCursor();

protected:
    /**
     * Line data.
     */
	std::unique_ptr<RS_LineData> data;
    /**
     * 2 points
     */
    RS_Vector p1;
    RS_Vector p2;
};

#endif

==> librecad_2.2.0.2.orig.tar.gz: LibreCAD-2.2.0.2/librecad/src/actions/rs_actiondrawlinehorvert.h <==
/****************************************************************************
**
** This file is part of the LibreCAD project, a 2D CAD program
**
** Copyright (C) 2010 R. van Twisk (librecad@rvt.dds.nl)
** Copyright (C) 2001-2003 RibbonSoft. All rights reserved.
**
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software 
** Foundation and appearing in the file gpl-2.0.txt included in the
** packaging of this file.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
** This copyright notice MUST APPEAR in all copies of the script!  
**
**********************************************************************/

#ifndef RS_ACTIONDRAWLINEHORVERT_H
#define RS_ACTIONDRAWLINEHORVERT_H

#include "rs_previewactioninterface.h"

/**
 * This action class can handle user events to draw 
 * horizontal/vertical lines from a given startpoint
 * to an endpoint closest to a second given point.
 * OBSOLETE
 *
 * @author Ulf Lehnert
 */
class RS_ActionDrawLineHorVert : public RS_PreviewActionInterface {
	Q_OBJECT
public:
    /**
     * Action States.
     */
    enum Status {
        SetStartpoint,      /**< Setting the 1st point.  */
        SetEndpoint       /**< Setting the 2nd point. */
    };

public:
    RS_ActionDrawLineHorVert(RS_EntityContainer& container,
                             RS_GraphicView& graphicView);
	~RS_ActionDrawLineHorVert() override;

    void reset();

	void init(int status=0) override;
	void trigger() override;
	void mouseMoveEvent(QMouseEvent* e) override;
	void mouseReleaseEvent(QMouseEvent* e) override;
	void updateMouseButtonHints() override;
	void updateMouseCursor() override;

protected:
	struct Points;
	std::unique_ptr<Points> pPoints;
};

#endif
